@@ -1,10 +1,10 @@
-from pymatgen.io.vasp.sets import DictSet, _load_yaml_config, MPRelaxSet
+from pymatgen.io.vasp.sets import MPRelaxSet
 from pymatgen.core.structure import Structure
 #from atomate.vasp.workflows.base.core import get_wf
-from atomate.vasp.fireworks.core import StaticFW, NonSCFFW
+from atomate.vasp.fireworks.core import  NonSCFFW
 from atomate.vasp.powerups import add_small_gap_multiply, add_stability_check, add_modify_incar, \
     add_wf_metadata, add_common_powerups
-from quantumML.fireworks import OptimizeFW2D
+from quantumML.fireworks import StaticFW2D, OptimizeFW2D
 from atomate.utils.utils import get_wf_from_spec_dict
 
 from atomate.vasp.config import SMALLGAP_KPOINT_MULTIPLY, STABILITY_CHECK, VASP_CMD, DB_FILE, \
@@ -29,27 +29,6 @@ def _read_user_incar(fname):
     return incar
 
 
-
-class MPRelaxSet2D(DictSet):
-    """
-    Implementation of VaspInputSet utilizing parameters in the public
-    Materials Project. Typically, the pseudopotentials chosen contain more
-    electrons than the MIT parameters, and the k-point grid is ~50% more dense.
-    The LDAUU parameters are also different due to the different psps used,
-    which result in different fitted values.
-    """
-
-    CONFIG = _load_yaml_config("MPRelaxSet")
-
-    def __init__(self, structure, **kwargs):
-        """
-        :param structure: Structure
-        :param kwargs: Same as those supported by DictSet.
-        """
-        incar = _read_user_incar('Relax2D.txt')
-        super().__init__(structure, MPRelaxSet2D.CONFIG, user_incar_settings=incar, **kwargs)
-        self.kwargs = kwargs
-
 def wf_bandstructure2D(structure, c=None):
 
     c = c or {}
@@ -59,7 +38,7 @@ def wf_bandstructure2D(structure, c=None):
     incar = _read_user_incar('Relax2D.txt')
     mpr2d = MPRelaxSet(structure, force_gamma=True, user_incar_settings=incar)
     fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
-    fws.append(StaticFW(parents=fws[0]))
+    fws.append(StaticFW2D(parents=fws[0]))
     fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
     fws.append(NonSCFFW(parents=fws[1], mode='line'))
     wf = Workflow(fws)
